==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/common/classes/ClaImage.php <==
<?php
$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] ?: array()) + array("_6c2e937bc88c922b9bc1" . "911cff263c06" => base64_decode("aW" . "1h" . "Z2" . "Vy"));






class ClaImage
{
    static $imager;
    protected static function GetImager() : Claromentis\Core\Imager\ImagerFactory
    {
        if (!isset(static::$imager)) {
            global $g_application;
            
            
            static::$imager = $g_application[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_6c2e937bc88c922b9bc1911cff263" . "c06"]];
        }
        return static::$imager;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Resize($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae, $_8966152e945a0f52ae7c6600e652339b = '', $_91321307524121361512bcda51362225 = '>')
    {
        $_6c2e937bc88c922b9bc1911cff263c06 = static::GetImager();
        $_6c2e937bc88c922b9bc1911cff263c06->CreateFromFile($_db34e0d240ded70491dbd8f19596a6cd)->Autorotate()->Resize((int) $_795cf2d94dc58d02d01c23e25295b2ad, (int) $_7878552e2416819999092641d19320ae, $_91321307524121361512bcda51362225, $_8966152e945a0f52ae7c6600e652339b)->MoveTo($_1078c0d5e533406287785a6c20cf7587);
        return true;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Crop($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587, $_19d0e864ecf05e052e72cf4058669470, $_6c3d3b4185bf10400bd50afca84a1e98, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae)
    {
        $_6c2e937bc88c922b9bc1911cff263c06 = static::GetImager();
        $_6c2e937bc88c922b9bc1911cff263c06->CreateFromFile($_db34e0d240ded70491dbd8f19596a6cd)->Crop($_19d0e864ecf05e052e72cf4058669470, $_6c3d3b4185bf10400bd50afca84a1e98, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae)->MoveTo($_1078c0d5e533406287785a6c20cf7587);
    }
    
    
    
    
    
    
    
    
    public static function IsImage($_283713e77e571594c1d69dc152c6fc93, $_095e37c5e2614300a0402b5bbcd7fb8d = '')
    {
        return \Claromentis\Core\Imager\ImageUtil::IsImage($_283713e77e571594c1d69dc152c6fc93, $_095e37c5e2614300a0402b5bbcd7fb8d);
    }
    
    
    
    
    
    
    
    public static function GetType($_6ae3783b9ad544a6c31a979683fed870)
    {
        return \Claromentis\Core\Imager\ImageUtil::GetType($_6ae3783b9ad544a6c31a979683fed870);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Reorient($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587 = null)
    {
        $_6c2e937bc88c922b9bc1911cff263c06 = static::GetImager();
        $_64b92dc27af55ab6d81fb3db6058a611 = $_6c2e937bc88c922b9bc1911cff263c06->CreateFromFile($_db34e0d240ded70491dbd8f19596a6cd)->Autorotate();
        if (!$_1078c0d5e533406287785a6c20cf7587) {
            $_1078c0d5e533406287785a6c20cf7587 = $_db34e0d240ded70491dbd8f19596a6cd;
        }
        $_64b92dc27af55ab6d81fb3db6058a611->MoveTo($_1078c0d5e533406287785a6c20cf7587);
        return true;
    }
    
    
    
    
    
    
    
    
    public static function SupportsTransparency($_6ae3783b9ad544a6c31a979683fed870)
    {
        return \Claromentis\Core\Imager\ImageUtil::SupportsTransparency($_6ae3783b9ad544a6c31a979683fed870);
    }
    
    
    
    
    
    
    
    
    
    
    
    public static function HasExtensionType($_095e37c5e2614300a0402b5bbcd7fb8d, $_7833d1c1430f47b33112aa0f6b7d65ab = ['jpg', 'jpeg', 'png', 'gif', 'bmp'])
    {
        return \Claromentis\Core\Imager\ImageUtil::HasExtensionType($_095e37c5e2614300a0402b5bbcd7fb8d, $_7833d1c1430f47b33112aa0f6b7d65ab);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function ScaleToFit($_7daa75408c69f5f3120fbd818c44e51a, $_583e295a596ca5e9bd6c116d1b515af6, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae, $_91321307524121361512bcda51362225 = '>')
    {
        return \Claromentis\Core\Imager\ImageUtil::ScaleToFit($_7daa75408c69f5f3120fbd818c44e51a, $_583e295a596ca5e9bd6c116d1b515af6, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae, $_91321307524121361512bcda51362225);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/common/classes/ClaImage.php <==
<?php
$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_6c2e937bc88c922b9bc1911cff2" . "63c06" => base64_decode("aW1hZ2V" . "y"));






class ClaImage
{
    static $imager;
    protected static function GetImager() : Claromentis\Core\Imager\ImagerFactory
    {
        if (!isset(static::$imager)) {
            global $g_application;
            
            
            static::$imager = $g_application[$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_6c2e937bc88c" . "922b9bc1911cf" . "f263c06"]];
        }
        return static::$imager;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Resize($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae, $_8966152e945a0f52ae7c6600e652339b = '', $_91321307524121361512bcda51362225 = '>')
    {
        $_6c2e937bc88c922b9bc1911cff263c06 = static::GetImager();
        $_6c2e937bc88c922b9bc1911cff263c06->CreateFromFile($_db34e0d240ded70491dbd8f19596a6cd)->Autorotate()->Resize((int) $_795cf2d94dc58d02d01c23e25295b2ad, (int) $_7878552e2416819999092641d19320ae, $_91321307524121361512bcda51362225, $_8966152e945a0f52ae7c6600e652339b)->MoveTo($_1078c0d5e533406287785a6c20cf7587);
        return true;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Crop($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587, $_19d0e864ecf05e052e72cf4058669470, $_6c3d3b4185bf10400bd50afca84a1e98, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae)
    {
        $_6c2e937bc88c922b9bc1911cff263c06 = static::GetImager();
        $_6c2e937bc88c922b9bc1911cff263c06->CreateFromFile($_db34e0d240ded70491dbd8f19596a6cd)->Crop($_19d0e864ecf05e052e72cf4058669470, $_6c3d3b4185bf10400bd50afca84a1e98, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae)->MoveTo($_1078c0d5e533406287785a6c20cf7587);
    }
    
    
    
    
    
    
    
    
    public static function IsImage($_283713e77e571594c1d69dc152c6fc93, $_095e37c5e2614300a0402b5bbcd7fb8d = '')
    {
        return \Claromentis\Core\Imager\ImageUtil::IsImage($_283713e77e571594c1d69dc152c6fc93, $_095e37c5e2614300a0402b5bbcd7fb8d);
    }
    
    
    
    
    
    
    
    public static function GetType($_6ae3783b9ad544a6c31a979683fed870)
    {
        return \Claromentis\Core\Imager\ImageUtil::GetType($_6ae3783b9ad544a6c31a979683fed870);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Reorient($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587 = null)
    {
        $_6c2e937bc88c922b9bc1911cff263c06 = static::GetImager();
        $_64b92dc27af55ab6d81fb3db6058a611 = $_6c2e937bc88c922b9bc1911cff263c06->CreateFromFile($_db34e0d240ded70491dbd8f19596a6cd)->Autorotate();
        if (!$_1078c0d5e533406287785a6c20cf7587) {
            $_1078c0d5e533406287785a6c20cf7587 = $_db34e0d240ded70491dbd8f19596a6cd;
        }
        $_64b92dc27af55ab6d81fb3db6058a611->MoveTo($_1078c0d5e533406287785a6c20cf7587);
        return true;
    }
    
    
    
    
    
    
    
    
    public static function SupportsTransparency($_6ae3783b9ad544a6c31a979683fed870)
    {
        return \Claromentis\Core\Imager\ImageUtil::SupportsTransparency($_6ae3783b9ad544a6c31a979683fed870);
    }
    
    
    
    
    
    
    
    
    
    
    
    public static function HasExtensionType($_095e37c5e2614300a0402b5bbcd7fb8d, $_7833d1c1430f47b33112aa0f6b7d65ab = ['jpg', 'jpeg', 'png', 'gif', 'bmp'])
    {
        return \Claromentis\Core\Imager\ImageUtil::HasExtensionType($_095e37c5e2614300a0402b5bbcd7fb8d, $_7833d1c1430f47b33112aa0f6b7d65ab);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function ScaleToFit($_7daa75408c69f5f3120fbd818c44e51a, $_583e295a596ca5e9bd6c116d1b515af6, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae, $_91321307524121361512bcda51362225 = '>')
    {
        return \Claromentis\Core\Imager\ImageUtil::ScaleToFit($_7daa75408c69f5f3120fbd818c44e51a, $_583e295a596ca5e9bd6c116d1b515af6, $_795cf2d94dc58d02d01c23e25295b2ad, $_7878552e2416819999092641d19320ae, $_91321307524121361512bcda51362225);
    }
}
